==> soxo-bootstrap-core-2.2.59.tgz: package/core/lib/elements/index.js <==
/**
 *
 * All the basic elements of the core library
 *
 *
 * We are creating wrappers for all existing components so that
 * we can build a design system .
 *
 *
 */

// Typography elements

import Title from './basic/title/title';

// Typography elements Ends

// Loaders

import Skeleton from './basic/skeleton/skeleton';

// Loaders Ends

// Buttons

// Buttons Ends

// Table

import BasicTable from './complex/basic-table/basic-table';

import Table from './basic/table/table';

import Modal from './basic/modal/modal';

import Select from './basic/select/select';

import Tag from './basic/tag/tag';

// Table Ends

// Card

import Card from './basic/card/card';

// Card Ends

// Image Starts
import Image from './basic/image/image';

import ImageWrapper from '../components/image-wrapper/image-wrapper';

import { PdfViewer } from '../components';

// Image Ends

// Modal

// Modal Ends

// Form Elements

import Form from './basic/form/form';

import InputComponent from './basic/input/input';

import FileUpload from '../components/file-upload/file-upload';

import CountryPhoneInput from './basic/country-phone-input/country-phone-input';

// Select Box

import SelectBox from './basic/select-box/select-box';

import ReferenceSelect from './basic/reference-select/reference-select';

import DatePicker from './basic/datepicker/datepicker';
// import SelectBox from "./basic/select-box/select-box";

// import ReferenceSelect from "./basic/reference-select/reference-select";

// Select Box Ends

import Switch from './basic/switch/switch';

import Button from './basic/button/button';

import RangePicker from './basic/rangepicker/rangepicker';

import Checkbox from './basic/checkbox/checkbox';

import JSONInput from './basic/json-input/json-input';

// Form Elements Ends

// Graph Elements

import PieChart from './complex/pie-chart/pie-chart';

import LineGraph from './complex/line-graph/line-graph';

import BarGraph from './complex/bargraph/bar-graph';

import StatisticCard from './complex/statistic-card/statistic-card';

// Graph Elements Ends

// Maps

import GoogleMap from './complex/google-map/google-map';

// import MapContainer from './complex/google-location-input/map-container-library-load'

import LocationSearchInput from './complex/location-search-input/location-search-input';

// Maps Ends

// Interfaces

import CopyToClipBoard from './basic/copy-to-clipboard/copy-to-clipboard';

import QRcode from './complex/qr-code/qr-code';

import Barcode from './complex/barcode/barcode';

import Popconfirm from './basic/popconfirm/popconfirm';

// Interfaces Ends

//import  GoogleApiWrapper  from 'google-maps-react';
// import ImageViewer from './basic/image-viewer/image-viewer';
// import ScriptInput from '../components/script-input/script-input';
// import PopQueryDashboard from './complex/pop-query-dashboard';

import UserSearch from './basic/user-search/user-search';

import Radio from './basic/radio/radio';

import Popover from './basic/popover/popover';

import Tabs from './basic/tab/tab';

import Empty from './basic/empty/empty';

import Space from './basic/space/space';

import Row from './basic/row/row';

import Col from './basic/col/col';

import TimeLine from './basic/timeline/timeline';

// import message from './basic/message/message'
// import UserSearch from "./basic/user-search/user-search";

export {
  // Typography Elements
  Title,

  // Typography Elements Ends

  // Loaders
  Skeleton,
  TimeLine,
  Row,
  Col,
  Tabs,
  Empty,
  Space,
  // message,

  // Loaders Ends

  // Form Elements
  Form,
  DatePicker,
  Tag,
  Popconfirm,
  Popover,

  // Form Elements Ends
  Select,
  SelectBox,
  ReferenceSelect,
  Switch,
  Modal,
  Button,
  Radio,
  Card,
  Table,
  QRcode,
  Barcode,
  RangePicker,
  JSONInput,
  BasicTable,
  LineGraph,
  BarGraph,
  StatisticCard,
  // SelectBox,
  // PopQueryDashboard,
  CopyToClipBoard,
  LocationSearchInput,
  //GoogleApiWrapper,
  // MapContainer,
  PieChart,
  GoogleMap,
  InputComponent,
  CountryPhoneInput,
  PdfViewer,

  // ImageViewer
  Image,
  FileUpload,
  ImageWrapper,
  UserSearch,
  Checkbox,
  // ScriptInput
};

==> soxo-bootstrap-core-2.2.88.tgz: package/core/lib/elements/index.js <==
/**
 *
 * All the basic elements of the core library
 *
 *
 * We are creating wrappers for all existing components so that
 * we can build a design system .
 *
 *
 */

// Typography elements

import Title from './basic/title/title';

// Typography elements Ends

// Loaders

import Skeleton from './basic/skeleton/skeleton';

// Loaders Ends

// Buttons

// Buttons Ends

// Table

import BasicTable from './complex/basic-table/basic-table';

import Table from './basic/table/table';

import Modal from './basic/modal/modal';

import Select from './basic/select/select';

import Tag from './basic/tag/tag';

// Table Ends

// Card

import Card from './basic/card/card';

// Card Ends

// Image Starts
import Image from './basic/image/image';

import ImageWrapper from '../components/image-wrapper/image-wrapper';

// import { PdfViewer } from '../components';

// Image Ends

// Modal

// Modal Ends

// Form Elements

import Form from './basic/form/form';

import InputComponent from './basic/input/input';

import FileUpload from '../components/file-upload/file-upload';

import CountryPhoneInput from './basic/country-phone-input/country-phone-input';

// Select Box

import SelectBox from './basic/select-box/select-box';

import ReferenceSelect from './basic/reference-select/reference-select';

import DatePicker from './basic/datepicker/datepicker';
// import SelectBox from "./basic/select-box/select-box";

// import ReferenceSelect from "./basic/reference-select/reference-select";

// Select Box Ends

import Switch from './basic/switch/switch';

import Button from './basic/button/button';

import RangePicker from './basic/rangepicker/rangepicker';

import Checkbox from './basic/checkbox/checkbox';

import JSONInput from './basic/json-input/json-input';

// Form Elements Ends

// Graph Elements

import PieChart from './complex/pie-chart/pie-chart';

import LineGraph from './complex/line-graph/line-graph';

import BarGraph from './complex/bargraph/bar-graph';

import StatisticCard from './complex/statistic-card/statistic-card';

// Graph Elements Ends

// Maps

import GoogleMap from './complex/google-map/google-map';

// import MapContainer from './complex/google-location-input/map-container-library-load'

import LocationSearchInput from './complex/location-search-input/location-search-input';

// Maps Ends

// Interfaces

import CopyToClipBoard from './basic/copy-to-clipboard/copy-to-clipboard';

import QRcode from './complex/qr-code/qr-code';

import Barcode from './complex/barcode/barcode';

import Popconfirm from './basic/popconfirm/popconfirm';

// Interfaces Ends

//import  GoogleApiWrapper  from 'google-maps-react';
// import ImageViewer from './basic/image-viewer/image-viewer';
// import ScriptInput from '../components/script-input/script-input';
// import PopQueryDashboard from './complex/pop-query-dashboard';

import UserSearch from './basic/user-search/user-search';

import Radio from './basic/radio/radio';

import Popover from './basic/popover/popover';

import Tabs from './basic/tab/tab';

import Empty from './basic/empty/empty';

import Space from './basic/space/space';

import Row from './basic/row/row';

import Col from './basic/col/col';

import TimeLine from './basic/timeline/timeline';

// import message from './basic/message/message'
// import UserSearch from "./basic/user-search/user-search";

export {
  // Typography Elements
  Title,

  // Typography Elements Ends

  // Loaders
  Skeleton,
  TimeLine,
  Row,
  Col,
  Tabs,
  Empty,
  Space,
  // message,

  // Loaders Ends

  // Form Elements
  Form,
  DatePicker,
  Tag,
  Popconfirm,
  Popover,

  // Form Elements Ends
  Select,
  SelectBox,
  ReferenceSelect,
  Switch,
  Modal,
  Button,
  Radio,
  Card,
  Table,
  QRcode,
  Barcode,
  RangePicker,
  JSONInput,
  BasicTable,
  LineGraph,
  BarGraph,
  StatisticCard,
  // SelectBox,
  // PopQueryDashboard,
  CopyToClipBoard,
  LocationSearchInput,
  //GoogleApiWrapper,
  // MapContainer,
  PieChart,
  GoogleMap,
  InputComponent,
  CountryPhoneInput,
  // PdfViewer,

  // ImageViewer
  Image,
  FileUpload,
  ImageWrapper,
  UserSearch,
  Checkbox,
  // ScriptInput
};
